%%  MASTER'S THESIS  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   This file is a part of a master's thesis by Johan Fredrik Holm Totland
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%	PHYSICAL PARAMETERS  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   WELL BORE PARAMETERS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
L = 10000;                  % Length of pipe [m]
r = 0.1;                    % Mean radius [m]
v = 30e-6;                  % Mean kinematic viscosity [m^2/s]
beta = 1.4e9;               % Bulk modulus [Pa]
rho = 1420;                 % Mean fluid density [kg/m^3]


%%	MODEL  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	GENERATE MODEL PARAMETERS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
c0 = sqrt(beta/rho);        % Mean speed of sound [m/s]
T = L/c0;                   % Time constant [s]
A0 = pi*r^2;                % Mean area [m^2]
Z0 = rho*c0/A0;             % Series impedanse
E = 8*v*T/r^2;              % Poiseuille friction coefficient


%%	TRANSFER FUNCTIONS  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%	LAPLACE OPERATOR
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
f = linspace(1e-3,3,1e4)';	% Frequency variable [rad]
s = 1i.*f;                  % Laplace transform variable
k = 1i.*(s/v).^.5;          % Bessel function argument

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   MODEL FROM Q1 TO P1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
m = 8;
modal = getQPmodel(m,E,T,Z0);
H_modal = freqresp(modal(1,1),f);
H_modal = squeeze(H_modal);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ANALYTICAL PDE FROM Q1 TO P1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
R = E/T;                                % Friction coefficient
Z_L = Z0;                               % Load impedance
Gamma_2D = T*s./(1-2*besselj(1,k*r)...  % Propegation operator
    ./(k*r.*besselj(0,k*r))).^.5;       % ...
Zc_2D = Z0/T*Gamma_2D./s;               % Characteristic line impedance
PDE_2D_inf = Zc_2D.*cosh(Gamma_2D)./sinh(Gamma_2D);
PDE_2D_zero = Zc_2D.*sinh(Gamma_2D)./cosh(Gamma_2D);
PDE_2D = Zc_2D.*(Z_L*cosh(Gamma_2D)+Zc_2D.*sinh(Gamma_2D))...
    ./(Zc_2D.*cosh(Gamma_2D)+Z_L*sinh(Gamma_2D));


%%  PLOT %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   FREQUENCY PLOT
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure; hold on; axis([0 2 0 3000]);
plot(f,abs(PDE_2D_zero)/(1e5), 'k','linewidth', 2);
plot(f,abs(H_modal)/(1e5), 'b','linewidth', 1);
xlabel('[rad/s]'); ylabel('Amplitude');
legend('PDE',['Modal method (',int2str(m),' modes)']);


